@@ -25,13 +25,17 @@ package org.apache.maven.it;
 class LauncherException
     extends Exception
 {
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
 
-    public LauncherException( String message )
+    LauncherException( String message )
     {
         super( message );
     }
 
-    public LauncherException( String message, Throwable cause )
+    LauncherException( String message, Throwable cause )
     {
         super( message, cause );
     }
