@@ -34,6 +34,8 @@ import java.io.PrintStream;
 import java.io.Writer;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.ArrayList;
@@ -50,8 +52,6 @@ import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
 
-import junit.framework.Assert;
-
 import org.apache.maven.shared.utils.StringUtils;
 import org.apache.maven.shared.utils.cli.CommandLineException;
 import org.apache.maven.shared.utils.cli.CommandLineUtils;
@@ -59,7 +59,7 @@ import org.apache.maven.shared.utils.cli.Commandline;
 import org.apache.maven.shared.utils.cli.StreamConsumer;
 import org.apache.maven.shared.utils.cli.WriterStreamConsumer;
 import org.apache.maven.shared.utils.io.FileUtils;
-import org.apache.maven.shared.utils.io.IOUtil;
+import org.junit.Assert;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
@@ -68,8 +68,6 @@ import org.xml.sax.helpers.DefaultHandler;
 /**
  * @author Jason van Zyl
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
- * @version $Id: Verifier.java 1683864 2015-06-05 20:41:57Z tibordigana $
- * @noinspection UseOfSystemOutOrSystemErr, RefusedBequest, UnusedDeclaration
  */
 public class Verifier
 {
@@ -105,23 +103,32 @@ public class Verifier
 
     private boolean debug;
 
+    /** 
+     * If {@code true} uses {@link ForkedLauncher}, if {@code false} uses {@link Embedded3xLauncher},
+     * otherwise considers the value {@link #forkMode}.
+     */
     private Boolean forkJvm;
 
     private String logFileName = LOG_FILENAME;
 
-    private String defaultMavenHome;
-
-    private String defaultClassworldConf;
-
-    private String defaultClasspath;
+    private String mavenHome;
 
     // will launch mvn with --debug 
     private boolean mavenDebug = false;
 
+    /**
+     * Either "auto" (use {@link ForkedLauncher} when {@link #environmentVariables} is not empty,
+     * otherwise use {@link Embedded3xLauncher}) , "embedder" (always use {@link Embedded3xLauncher})
+     * or something else (always use {@link ForkedLauncher}).
+     * Set through system property {@code verifier.forkMode}.
+     * Only relevant if {@link #forkJvm} is {@code null}.
+     */
     private String forkMode;
 
     private boolean debugJvm = false;
 
+    private boolean useWrapper;
+
     private static MavenLauncher embeddedLauncher;
 
     public Verifier( String basedir )
@@ -163,11 +170,23 @@ public class Verifier
     public Verifier( String basedir, String settingsFile, boolean debug, boolean forkJvm, String[] defaultCliOptions )
         throws VerificationException
     {
-        this( basedir, settingsFile, debug, (Boolean) forkJvm, defaultCliOptions );
+        this( basedir, settingsFile, debug, forkJvm, defaultCliOptions, null );
     }
 
-    private Verifier( String basedir, String settingsFile, boolean debug, Boolean forkJvm, String[] defaultCliOptions )
+    public Verifier( String basedir, String settingsFile, boolean debug, String mavenHome ) 
+            throws VerificationException
+    {
+        this( basedir, settingsFile, debug, null, DEFAULT_CLI_OPTIONS, mavenHome );
+    }
+
+    public Verifier( String basedir, String settingsFile, boolean debug, String mavenHome, String[] defaultCliOptions ) 
         throws VerificationException
+    {
+        this( basedir, settingsFile, debug, null, defaultCliOptions, mavenHome );
+    }
+
+    private Verifier( String basedir, String settingsFile, boolean debug, Boolean forkJvm, String[] defaultCliOptions,
+            String mavenHome ) throws VerificationException
     {
         this.basedir = basedir;
 
@@ -184,9 +203,18 @@ public class Verifier
         setDebug( debug );
 
         findLocalRepo( settingsFile );
-        findDefaultMavenHome();
+        if ( mavenHome == null )
+        {
+            this.mavenHome = getDefaultMavenHome();
+            useWrapper = Files.exists( Paths.get( getBasedir(), "mvnw" ) );
+        }
+        else
+        {
+            this.mavenHome = mavenHome;
+            useWrapper = false;
+        }
 
-        if ( StringUtils.isEmpty( defaultMavenHome ) && StringUtils.isEmpty( forkMode ) )
+        if ( StringUtils.isEmpty( mavenHome ) && StringUtils.isEmpty( forkMode ) )
         {
             forkMode = "auto";
         }
@@ -194,12 +222,9 @@ public class Verifier
         this.defaultCliOptions = defaultCliOptions == null ? new String[0] : defaultCliOptions.clone();
     }
 
-    private void findDefaultMavenHome()
-        throws VerificationException
+    private static String getDefaultMavenHome()
     {
-        defaultClasspath = System.getProperty( "maven.bootclasspath" );
-        defaultClassworldConf = System.getProperty( "classworlds.conf" );
-        defaultMavenHome = System.getProperty( "maven.home" );
+        String defaultMavenHome = System.getProperty( "maven.home" );
 
         if ( defaultMavenHome == null )
         {
@@ -215,6 +240,7 @@ public class Verifier
                 defaultMavenHome = f.getAbsolutePath();
             }
         }
+        return defaultMavenHome;
     }
 
     public void setLocalRepo( String localRepo )
@@ -281,7 +307,7 @@ public class Verifier
         for ( String line : lines )
         {
             // A hack to keep stupid velocity resource loader errors from triggering failure
-            if ( line.contains( "[ERROR]" ) && !isVelocityError( line ) )
+            if ( stripAnsi( line ).contains( "[ERROR]" ) && !isVelocityError( line ) )
             {
                 throw new VerificationException( "Error in execution: " + line );
             }
@@ -304,7 +330,7 @@ public class Verifier
      * Throws an exception if the text is not present in the log.
      *
      * @param text the text to assert present
-     * @throws VerificationException
+     * @throws VerificationException if text is not found in log
      */
     public void verifyTextInLog( String text )
         throws VerificationException
@@ -314,7 +340,7 @@ public class Verifier
         boolean result = false;
         for ( String line : lines )
         {
-            if ( line.contains( text ) )
+            if ( stripAnsi( line ).contains( text ) )
             {
                 result = true;
                 break;
@@ -326,30 +352,20 @@ public class Verifier
         }
     }
 
+    public static String stripAnsi( String msg )
+    {
+        return msg.replaceAll( "\u001B\\[[;\\d]*[ -/]*[@-~]", "" );
+    }
+
     public Properties loadProperties( String filename )
         throws VerificationException
     {
         Properties properties = new Properties();
 
-        try
+        File propertiesFile = new File( getBasedir(), filename );
+        try ( FileInputStream fis = new FileInputStream( propertiesFile ) ) 
         {
-            File propertiesFile = new File( getBasedir(), filename );
-            if ( propertiesFile.exists() )
-            {
-                FileInputStream fis = new FileInputStream( propertiesFile );
-                try
-                {
-                    properties.load( fis );
-                }
-                finally
-                {
-                    fis.close();
-                }
-            }
-        }
-        catch ( FileNotFoundException e )
-        {
-            throw new VerificationException( "Error reading properties file", e );
+            properties.load( fis );
         }
         catch ( IOException e )
         {
@@ -374,20 +390,8 @@ public class Verifier
     {
         List<String> lines = new ArrayList<String>();
 
-        File file = new File( getBasedir(), filename );
-
-        BufferedReader reader = null;
-        try
+        try ( BufferedReader reader = getReader( filename, encoding ) )
         {
-            if ( StringUtils.isNotEmpty( encoding ) )
-            {
-                reader = new BufferedReader( new InputStreamReader( new FileInputStream( file ), encoding ) );
-            }
-            else
-            {
-                reader = new BufferedReader( new FileReader( file ) );
-            }
-
             String line;
             while ( ( line = reader.readLine() ) != null )
             {
@@ -397,14 +401,24 @@ public class Verifier
                 }
             }
         }
-        finally
-        {
-            IOUtil.close( reader );
-        }
 
         return lines;
     }
 
+    private BufferedReader getReader( String filename, String encoding ) throws IOException
+    {
+        File file = new File( getBasedir(), filename );
+
+        if ( StringUtils.isNotEmpty( encoding ) )
+        {
+            return new BufferedReader( new InputStreamReader( new FileInputStream( file ), encoding ) );
+        }
+        else
+        {
+            return new BufferedReader( new FileReader( file ) );
+        }
+    }
+
     public List<String> loadFile( String basedir, String filename, boolean hasCommand )
         throws VerificationException
     {
@@ -416,14 +430,10 @@ public class Verifier
     {
         List<String> lines = new ArrayList<String>();
 
-        BufferedReader reader = null;
-
         if ( file.exists() )
         {
-            try
+            try ( BufferedReader reader = new BufferedReader( new FileReader( file ) ) )
             {
-                reader = new BufferedReader( new FileReader( file ) );
-
                 String line = reader.readLine();
 
                 while ( line != null )
@@ -436,8 +446,6 @@ public class Verifier
                     }
                     line = reader.readLine();
                 }
-
-                reader.close();
             }
             catch ( FileNotFoundException e )
             {
@@ -447,10 +455,6 @@ public class Verifier
             {
                 throw new VerificationException( e );
             }
-            finally
-            {
-                IOUtil.close( reader );
-            }
         }
 
         return lines;
@@ -547,16 +551,16 @@ public class Verifier
             a[i] = tok.nextToken();
         }
 
-        String org = a[0];
-        String name = a[1];
+        String groupId = a[0];
+        String artifactId = a[1];
         String version = a[2];
         String ext = a[3];
-        return getArtifactPath( org, name, version, ext );
+        return getArtifactPath( groupId, artifactId, version, ext );
     }
 
-    public String getArtifactPath( String org, String name, String version, String ext )
+    public String getArtifactPath( String groupId, String artifactId, String version, String ext )
     {
-        return getArtifactPath( org, name, version, ext, null );
+        return getArtifactPath( groupId, artifactId, version, ext, null );
     }
 
     /**
@@ -793,23 +797,22 @@ public class Verifier
 
             cli.setWorkingDirectory( basedir );
 
-            Writer logWriter = new FileWriter( new File( basedir, LOG_FILENAME ) );
-
-            StreamConsumer out = new WriterStreamConsumer( logWriter );
-
-            StreamConsumer err = new WriterStreamConsumer( logWriter );
-
-            System.out.println( "Command: " + CommandLineUtils.toString( cli.getCommandline() ) );
-
-            int ret = CommandLineUtils.executeCommandLine( cli, out, err );
-
-            logWriter.close();
-
-            if ( ret > 0 )
+            try ( Writer logWriter = new FileWriter( new File( basedir, LOG_FILENAME ) ) ) 
             {
-                System.err.println( "Exit code: " + ret );
+                StreamConsumer out = new WriterStreamConsumer( logWriter );
 
-                throw new VerificationException();
+                StreamConsumer err = new WriterStreamConsumer( logWriter );
+
+                System.out.println( "Command: " + CommandLineUtils.toString( cli.getCommandline() ) );
+
+                int ret = CommandLineUtils.executeCommandLine( cli, out, err );
+
+                if ( ret > 0 )
+                {
+                    System.err.println( "Exit code: " + ret );
+
+                    throw new VerificationException();
+                }
             }
         }
         catch ( CommandLineException e )
@@ -984,8 +987,18 @@ public class Verifier
      * There are 226 references to this method in Maven core ITs. In most (all?) cases it is used together with
      * {@link #newDefaultFilterProperties()}. Need to remove both methods and update all clients eventually/
      * 
+     * @param srcPath          The path to the input file, relative to the base directory, must not be
+     *                         <code>null</code>.
+     * @param dstPath          The path to the output file, relative to the base directory and possibly equal to the
+     *                         input file, must not be <code>null</code>.
+     * @param fileEncoding     The file encoding to use, may be <code>null</code> or empty to use the platform's default
+     *                         encoding.
+     * @param filterProperties The mapping from tokens to replacement values, must not be <code>null</code>.
+     * @return The path to the filtered output file, never <code>null</code>.
+     * @throws IOException If the file could not be filtered.
      * @deprecated use {@link #filterFile(String, String, String, Map)}
      */
+    @Deprecated
     @SuppressWarnings( { "rawtypes", "unchecked" } )
     public File filterFile( String srcPath, String dstPath, String fileEncoding, Properties filterProperties )
         throws IOException
@@ -1022,11 +1035,28 @@ public class Verifier
         return filterProperties;
     }
 
+    /**
+     * Verifies that the given file exists.
+     * 
+     * @param file the path of the file to check
+     * @throws VerificationException in case the given file does not exist
+     */
+    public void verifyFilePresent( String file ) throws VerificationException
+    {
+        verifyFilePresence( file, true );
+    }
+
+    /**
+     * 
+     * @param file the path of the file to check
+     * @deprecated Use {@link #verifyFilePresent(String)} instead.
+     */
+    @Deprecated
     public void assertFilePresent( String file )
     {
         try
         {
-            verifyExpectedResult( file, true );
+            verifyFilePresent( file );
         }
         catch ( VerificationException e )
         {
@@ -1035,35 +1065,46 @@ public class Verifier
     }
 
     /**
-     * Check that given file's content matches an regular expression. Note this method also checks that the file exists
-     * and is readable.
+     * Verifies the given file's content matches an regular expression. 
+     * Note this method also checks that the file exists and is readable.
      *
-     * @param file  the file to check.
-     * @param regex a regular expression.
+     * @param file the path of the file to check
+     * @param regex a regular expression
+     * @throws VerificationException in case the file was not found or its content does not match the given pattern
      * @see Pattern
      */
-    public void assertFileMatches( String file, String regex )
+    public void verifyFileContentMatches( String file, String regex ) throws VerificationException
     {
-        assertFilePresent( file );
+        verifyFilePresent( file );
         try
         {
             String content = FileUtils.fileRead( file );
             if ( !Pattern.matches( regex, content ) )
             {
-                Assert.fail( "Content of " + file + " does not match " + regex );
+                throw new VerificationException( "Content of " + file + " does not match " + regex );
             }
         }
         catch ( IOException e )
         {
-            Assert.fail( e.getMessage() );
+            throw new VerificationException( "Could not read from " + file + ": " + e.getMessage(), e );
         }
     }
 
-    public void assertFileNotPresent( String file )
+    /**
+     * Check the given file's content matches a regular expression. Note this method also checks that the file exists
+     * and is readable.
+     *
+     * @param file the path of the file to check
+     * @param regex a regular expression that the file's contents should match
+     * @see Pattern
+     * @deprecated Use {@link #verifyFileContentMatches(String, String)} instead.
+     */
+    @Deprecated
+    public void assertFileMatches( String file, String regex )
     {
         try
         {
-            verifyExpectedResult( file, false );
+            verifyFileContentMatches( file, regex );
         }
         catch ( VerificationException e )
         {
@@ -1071,30 +1112,103 @@ public class Verifier
         }
     }
 
-    private void verifyArtifactPresence( boolean wanted, String org, String name, String version, String ext )
+    /**
+     * Verifies that the given file does not exist.
+     * 
+     * @param file the path of the file to check
+     * @throws VerificationException if the given file exists
+     */
+    public void verifyFileNotPresent( String file ) throws VerificationException
     {
-        List<String> files = getArtifactFileNameList( org, name, version, ext );
-        for ( String fileName : files )
+        verifyFilePresence( file, false );
+    }
+
+    /**
+     * 
+     * @param file the path of the file to check
+     * @deprecated Use {@link #verifyFileNotPresent(String)} instead.
+     */
+    @Deprecated
+    public void assertFileNotPresent( String file )
+    {
+        try
         {
-            try
-            {
-                verifyExpectedResult( fileName, wanted );
-            }
-            catch ( VerificationException e )
-            {
-                Assert.fail( e.getMessage() );
-            }
+            verifyFileNotPresent( file );
+        }
+        catch ( VerificationException e )
+        {
+            Assert.fail( e.getMessage() );
         }
     }
 
-    public void assertArtifactPresent( String org, String name, String version, String ext )
+    private void verifyArtifactPresence( boolean wanted, String groupId, String artifactId, String version, String ext )
+                    throws VerificationException
     {
-        verifyArtifactPresence( true, org, name, version, ext );
+        List<String> files = getArtifactFileNameList( groupId, artifactId, version, ext );
+        for ( String fileName : files )
+        {
+            verifyFilePresence( fileName, wanted );
+        }
     }
 
+    /**
+     * Verifies that the artifact given through its Maven coordinates exists.
+     * 
+     * @param groupId the groupId of the artifact (must not be null)
+     * @param artifactId the artifactId of the artifact (must not be null)
+     * @param version the version of the artifact (must not be null)
+     * @param ext the extension of the artifact (must not be null)
+     * @throws VerificationException if the given artifact does not exist
+     */
+    public void verifyArtifactPresent( String groupId, String artifactId, String version, String ext )
+                    throws VerificationException
+    {
+        verifyArtifactPresence( true, groupId, artifactId, version, ext );
+    }
+
+    /**
+     * Verifies that the artifact given through its Maven coordinates does not exist.
+     * 
+     * @param groupId the groupId of the artifact (must not be null)
+     * @param artifactId the artifactId of the artifact (must not be null)
+     * @param version the version of the artifact (must not be null)
+     * @param ext the extension of the artifact (must not be null)
+     * @throws VerificationException if the given artifact exists
+     */
+    public void verifyArtifactNotPresent( String groupId, String artifactId, String version, String ext )
+                    throws VerificationException
+    {
+        verifyArtifactPresence( false, groupId, artifactId, version, ext );
+    }
+
+    private void assertArtifactPresence( boolean wanted, String org, String name, String version, String ext )
+    {
+        try
+        {
+            verifyArtifactPresence( wanted, org, name, version, ext );
+        }
+        catch ( VerificationException e )
+        {
+            Assert.fail( e.getMessage() );
+        }
+    }
+
+    /**
+     * @deprecated Use {@link #verifyArtifactPresent(String, String, String, String)} instead.
+     */
+    @Deprecated
+    public void assertArtifactPresent( String org, String name, String version, String ext )
+    {
+        assertArtifactPresence( true, org, name, version, ext );
+    }
+
+    /**
+     * @deprecated Use {@link #verifyArtifactNotPresent(String, String, String, String)} instead.
+     */
+    @Deprecated
     public void assertArtifactNotPresent( String org, String name, String version, String ext )
     {
-        verifyArtifactPresence( false, org, name, version, ext );
+        assertArtifactPresence( false, org, name, version, ext );
     }
 
     private void verifyExpectedResult( String line )
@@ -1107,15 +1221,15 @@ public class Verifier
             wanted = false;
         }
 
-        verifyExpectedResult( line, wanted );
+        verifyFilePresence( line, wanted );
     }
 
-    private void verifyExpectedResult( String line, boolean wanted )
+    private void verifyFilePresence( String filePath, boolean wanted )
         throws VerificationException
     {
-        if ( line.indexOf( "!/" ) > 0 )
+        if ( filePath.indexOf( "!/" ) > 0 )
         {
-            String urlString = "jar:file:" + getBasedir() + "/" + line;
+            String urlString = "jar:file:" + getBasedir() + "/" + filePath;
 
             InputStream is = null;
             try
@@ -1128,14 +1242,14 @@ public class Verifier
                 {
                     if ( wanted )
                     {
-                        throw new VerificationException( "Expected JAR resource was not found: " + line );
+                        throw new VerificationException( "Expected JAR resource was not found: " + filePath );
                     }
                 }
                 else
                 {
                     if ( !wanted )
                     {
-                        throw new VerificationException( "Unwanted JAR resource was found: " + line );
+                        throw new VerificationException( "Unwanted JAR resource was found: " + filePath );
                     }
                 }
             }
@@ -1147,7 +1261,7 @@ public class Verifier
             {
                 if ( wanted )
                 {
-                    throw new VerificationException( "Error looking for JAR resource: " + line );
+                    throw new VerificationException( "Error looking for JAR resource: " + filePath );
                 }
             }
             finally
@@ -1167,15 +1281,15 @@ public class Verifier
         }
         else
         {
-            File expectedFile = new File( line );
+            File expectedFile = new File( filePath );
 
             // NOTE: On Windows, a path with a leading (back-)slash is relative to the current drive
             if ( !expectedFile.isAbsolute() && !expectedFile.getPath().startsWith( File.separator ) )
             {
-                expectedFile = new File( getBasedir(), line );
+                expectedFile = new File( getBasedir(), filePath );
             }
 
-            if ( line.indexOf( '*' ) > -1 )
+            if ( filePath.indexOf( '*' ) > -1 )
             {
                 File parent = expectedFile.getParentFile();
 
@@ -1265,8 +1379,6 @@ public class Verifier
         // Use a strategy for finding the maven executable, John has a simple method like this
         // but a little strategy + chain of command would be nicer.
 
-        String mavenHome = defaultMavenHome;
-
         if ( mavenHome != null )
         {
             return mavenHome + "/bin/mvn";
@@ -1367,7 +1479,7 @@ public class Verifier
             System.err.println( "Exit code: " + ret );
 
             throw new VerificationException(
-                "Exit code was non-zero: " + ret + "; command line and log = \n" + new File( defaultMavenHome,
+                "Exit code was non-zero: " + ret + "; command line and log = \n" + new File( mavenHome,
                                                                                              "bin/mvn" ) + " "
                     + StringUtils.join( args.iterator(), " " ) + "\n" + getLogContents( logFile ) );
         }
@@ -1377,7 +1489,11 @@ public class Verifier
         throws LauncherException
     {
         boolean fork;
-        if ( forkJvm != null )
+        if ( useWrapper )
+        {
+            fork = true;
+        }
+        else if ( forkJvm != null )
         {
             fork = forkJvm;
         }
@@ -1413,7 +1529,7 @@ public class Verifier
         }
         else
         {
-            return new ForkedLauncher( defaultMavenHome, envVars, debugJvm );
+            return new ForkedLauncher( mavenHome, envVars, debugJvm, useWrapper );
         }
     }
 
@@ -1422,39 +1538,41 @@ public class Verifier
     {
         if ( embeddedLauncher == null )
         {
-            if ( StringUtils.isEmpty( defaultMavenHome ) )
+            if ( StringUtils.isEmpty( mavenHome ) )
             {
                 embeddedLauncher = Embedded3xLauncher.createFromClasspath();
             }
             else
             {
-                embeddedLauncher =
-                    Embedded3xLauncher.createFromMavenHome( defaultMavenHome, defaultClassworldConf, getClasspath() );
+                String defaultClasspath = System.getProperty( "maven.bootclasspath" );
+                String defaultClassworldConf = System.getProperty( "classworlds.conf" );
+                embeddedLauncher = Embedded3xLauncher.createFromMavenHome( mavenHome, defaultClassworldConf, 
+                        parseClasspath( defaultClasspath ) );
             }
         }
     }
 
-    private List<URL> getClasspath()
+    private static List<URL> parseClasspath( String classpath )
         throws LauncherException
     {
-        if ( defaultClasspath == null )
+        if ( classpath == null )
         {
             return null;
         }
-        ArrayList<URL> classpath = new ArrayList<URL>();
-        StringTokenizer st = new StringTokenizer( defaultClasspath, File.pathSeparator );
+        ArrayList<URL> classpathUrls = new ArrayList<URL>();
+        StringTokenizer st = new StringTokenizer( classpath, File.pathSeparator );
         while ( st.hasMoreTokens() )
         {
             try
             {
-                classpath.add( new File( st.nextToken() ).toURI().toURL() );
+                classpathUrls.add( new File( st.nextToken() ).toURI().toURL() );
             }
             catch ( MalformedURLException e )
             {
-                throw new LauncherException( "Invalid launcher classpath " + defaultClasspath, e );
+                throw new LauncherException( "Invalid launcher classpath " + classpath, e );
             }
         }
-        return classpath;
+        return classpathUrls;
     }
 
     public String getMavenVersion()
@@ -1524,30 +1642,22 @@ public class Verifier
     private void displayLogFile()
     {
         System.out.println( "Log file contents:" );
-        BufferedReader reader = null;
-        try
+
+        try ( BufferedReader reader = 
+                        new BufferedReader( new FileReader( new File( getBasedir(), getLogFileName() ) ) ) )
         {
-            reader = new BufferedReader( new FileReader( new File( getBasedir(), getLogFileName() ) ) );
             String line = reader.readLine();
+            
             while ( line != null )
             {
                 System.out.println( line );
                 line = reader.readLine();
             }
-            reader.close();
-        }
-        catch ( FileNotFoundException e )
-        {
-            System.err.println( "Error: " + e );
         }
         catch ( IOException e )
         {
             System.err.println( "Error: " + e );
         }
-        finally
-        {
-            IOUtil.close( reader );
-        }
     }
 
     // ----------------------------------------------------------------------
@@ -1785,6 +1895,31 @@ public class Verifier
         System.out.println( "OK" );
     }
 
+    /**
+     * Verifies that the artifact given by its Maven coordinates exists and contains the given content.
+     * 
+     * @param groupId the groupId of the artifact (must not be null)
+     * @param artifactId the artifactId of the artifact (must not be null)
+     * @param version the version of the artifact (must not be null)
+     * @param ext the extension of the artifact (must not be null)
+     * @param content the expected content
+     * @throws IOException if reading from the artifact fails 
+     * @throws VerificationException if the content of the artifact differs
+     */
+    public void verifyArtifactContent( String groupId, String artifactId, String version, String ext, String content )
+        throws IOException, VerificationException
+    {
+        String fileName = getArtifactPath( groupId, artifactId, version, ext );
+        if ( content.equals( FileUtils.fileRead( fileName ) ) )
+        {
+            throw new VerificationException( "Content of " + fileName + " does not equal " + content );
+        }
+    }
+
+    /**
+     * @deprecated Use {@link #verifyArtifactContent(String, String, String, String, String)} instead.
+     */
+    @Deprecated
     public void assertArtifactContents( String org, String artifact, String version, String type, String contents )
         throws IOException
     {
